.. _manifests:

Manifests
=========

The ASDF tags (described by schemas) available under each ASDF transform schemas version are all described
by a single manifest document for that version.

.. asdf-autoschemas::
   :schema_root: ../resources/asdf-format.org
   :standard_prefix: manifests

   transform-1.0.0
   transform-1.1.0
   transform-1.2.0
   transform-1.3.0
   transform-1.4.0
   transform-1.5.0
